@@ -39,6 +39,7 @@ import stat
 import subprocess
 import sys
 import tinys3
+import time
 import traceback
 from github3 import login
 
@@ -243,13 +244,14 @@ try:
         # Add num of commits from libopenshot and libopenshot-audio (for naming purposes)
         # If not an official release
         if git_branch_name == "develop":
-            # Make filename more descriptive for daily builds
+            # Make filename more descriptive for daily builds (add time epoch)
+            openshot_qt_git_desc = "OpenShot-v%s-%d" % (info.VERSION, int(time.time()))
             openshot_qt_git_desc = "%s-%s-%s" % (openshot_qt_git_desc, version_info.get('libopenshot').get('CI_COMMIT_SHA')[:8], version_info.get('libopenshot-audio').get('CI_COMMIT_SHA')[:8])
             # Get daily git_release object
             github_release = get_release(repo, "daily")
         elif git_branch_name == "release":
             # Get daily git_release object
-            openshot_qt_git_desc = "OpenShot-v%s" % info.VERSION
+            openshot_qt_git_desc = "OpenShot-v%s-release-candidate-%d" % (info.VERSION, int(time.time()))
             github_release = get_release(repo, "daily")
         elif git_branch_name == "master":
             # Get official version release (i.e. v2.1.0, v2.x.x)
@@ -261,15 +263,13 @@ try:
                 github_release = repo.create_release(git_description, target_commitish="master", prerelease=True)
         else:
             # Make filename more descriptive for daily builds
+            openshot_qt_git_desc = "OpenShot-v%s-%d" % (info.VERSION, int(time.time()))
             openshot_qt_git_desc = "%s-%s-%s" % (openshot_qt_git_desc, version_info.get('libopenshot').get('CI_COMMIT_SHA')[:8], version_info.get('libopenshot-audio').get('CI_COMMIT_SHA')[:8])
             # Get daily git_release object
             github_release = get_release(repo, "daily")
             needs_upload = False
 
-    # Output git desription
-    output("git description of openshot-qt-git: %s" % openshot_qt_git_desc)
-
-    # Output git desription
+    # Output git description
     output("git description of openshot-qt-git: %s" % openshot_qt_git_desc)
 
     # Detect version number from git description
